Package: mrgsim.parallel
Type: Package
Title: Simulate with 'mrgsolve' in Parallel
Version: 0.3.0
Authors@R: c(
    person("Kyle", "Baron", "", "kylebtwin@imap.cc", c("aut", "cre"))
    )
Maintainer: Kyle Baron <kylebtwin@imap.cc>
Description: Simulation from an 'mrgsolve' 
    <https://cran.r-project.org/package=mrgsolve> model using a parallel backend.  
    Input data sets are split (chunked) and simulated in parallel using 
    mclapply() or future_lapply() 
    <https://cran.r-project.org/package=future.apply>.
License: GPL (>= 2)
Imports: parallel, dplyr, future, future.apply, callr, fst
Depends: mrgsolve, R (>= 3.5.0)
Suggests: testthat, arrow, qs, knitr, rmarkdown
Encoding: UTF-8
URL: https://github.com/kylebaron/mrgsim.parallel
BugReports: https://github.com/kylebaron/mrgsim.parallel/issues
RoxygenNote: 7.3.2
VignetteBuilder: knitr
Language: en-US
NeedsCompilation: no
Packaged: 2025-07-28 00:38:21 UTC; kyleb
Author: Kyle Baron [aut, cre]
Repository: CRAN
Date/Publication: 2025-07-28 12:20:02 UTC
Built: R 4.6.0; ; 2026-04-26 14:07:08 UTC; unix
