# Generated by roxygen2: do not edit by hand

S3method(new_stream,character)
S3method(new_stream,data.frame)
S3method(new_stream,list)
S3method(new_stream,numeric)
S3method(summary,file_stream)
S3method(write_stream,default)
S3method(write_stream,stream_format_feather)
S3method(write_stream,stream_format_fst)
S3method(write_stream,stream_format_parquet)
S3method(write_stream,stream_format_qs)
S3method(write_stream,stream_format_rds)
export(bg_mclapply)
export(bg_mrgsim_d)
export(chunk_by_cols)
export(chunk_by_id)
export(chunk_by_row)
export(ext_stream)
export(file_set)
export(file_stream)
export(format_is_set)
export(format_stream)
export(fu_mrgsim_d)
export(fu_mrgsim_d0)
export(fu_mrgsim_ei)
export(fu_mrgsim_ei0)
export(future_mrgsim_d)
export(future_mrgsim_ei)
export(get_fst)
export(head_fst)
export(internalize_fst)
export(is.file_set_item)
export(is.file_stream)
export(is.locker_stream)
export(is.stream_format)
export(is_locker_dir)
export(list_fst)
export(locate_stream)
export(mc_mrgsim_d)
export(mc_mrgsim_ei)
export(mrgsim_ms)
export(mrgsim_worker)
export(new_stream)
export(noreset_locker)
export(reset_locker)
export(setup_locker)
export(temp_ds)
export(version_locker)
export(write_stream)
importFrom(callr,r_bg)
importFrom(callr,rcmd_safe_env)
importFrom(dplyr,as_tibble)
importFrom(dplyr,bind_rows)
importFrom(dplyr,tibble)
importFrom(fst,read_fst)
importFrom(fst,write_fst)
importFrom(future,multicore)
importFrom(future,multisession)
importFrom(future,plan)
importFrom(future,sequential)
importFrom(future.apply,future_lapply)
importFrom(future.apply,future_mapply)
importFrom(mrgsolve,house)
importFrom(mrgsolve,loadso)
importFrom(mrgsolve,mrgsim)
importFrom(mrgsolve,mrgsim_d)
importFrom(mrgsolve,mrgsim_ei)
importFrom(mrgsolve,mrgsim_i)
importFrom(parallel,mclapply)
importFrom(parallel,mcmapply)
importFrom(tools,file_ext)
importFrom(tools,file_path_sans_ext)
importFrom(utils,assignInMyNamespace)
importMethodsFrom(mrgsolve,as.list)
