"","filename","functions","line","value"
"178","R/data_parallel.R","mc_mrgsim_d",80,0
"48","R/fst.R","internalize_fst",31,0
"4","R/locker.R","locker_tag",3,0
"325","R/locker.R","noreset_locker",162,0
"373","R/locker.R","version_locker",205,0
"391","R/locker.R","version_locker",218,0
"241","R/mrgsim-bg.R","bg_mrgsim_d",107,0
"254","R/mrgsim-bg.R","bg_mrgsim_d",115,0
"256","R/mrgsim-bg.R","bg_mrgsim_d",118,0
"268","R/mrgsim-bg.R","bg_mrgsim_d",128,0
"335","R/mrgsim-bg.R","bg_mrgsim_apply",173,0
"336","R/mrgsim-bg.R","bg_mrgsim_apply",174,0
"337","R/mrgsim-bg.R","bg_mrgsim_apply",175,0
"338","R/mrgsim-bg.R","bg_mrgsim_apply",176,0
"339","R/mrgsim-bg.R","bg_mrgsim_apply",177,0
"340","R/mrgsim-bg.R","bg_mrgsim_apply",178,0
"341","R/mrgsim-bg.R","bg_mrgsim_apply",179,0
"342","R/mrgsim-bg.R","bg_mrgsim_apply",180,0
"343","R/mrgsim-bg.R","bg_mrgsim_apply",181,0
"344","R/mrgsim-bg.R","bg_mrgsim_apply",182,0
"345","R/mrgsim-bg.R","bg_mrgsim_apply",183,0
"346","R/mrgsim-bg.R","bg_mrgsim_apply",184,0
"15","R/par_parallel.R",".simi",10,0
"221","R/par_parallel.R","mc_mrgsim_ei",97,0
"201","R/stream-file.R","file_stream",89,0
"91","R/stream-write.R","write_stream.default",49,0
"27","R/stream.R","write_stream_dir_check",18,0
"32","R/stream.R","write_stream_dir_check",21,0
"66","R/stream.R","is.locker_stream",38,0
"202","R/stream.R","new_stream.list",89,0
"295","R/stream.R","format_stream",146,0
"357","R/stream.R","locate_stream",194,0
"400","R/stream.R","ext_stream",224,0
"220","R/utils.R","mc_able",97,0
"235","R/utils.R","require_arrow",103,0
"245","R/utils.R","require_qs",109,0
